Model implementations.
This module contains pure model implementations that handle preprocessing, inference, and postprocessing. Models are independent of tasks and can be reused across different task adapters.
Modules
- classification
- Classification model implementations.
- detection
- Detection model implementations.
- recognition
- Recognition model implementations.
- rectification
- Rectification model implementations.